function r_v = predictTestSet(trainFileName,user_v,item_v)
% predict the ratings on test set
% Inputs: 
%  dataFileName: a mat File name where stores the model parameters:
%   mu, b_u,b_i,p_u, q_i,y_i w_ij, c_ij, S^k(i).
%  user_v,item_v: two column vectors with the same size, containing
%   user indices and item indices to predict
% Outputs:
%  r_v: a column vector containing predicted ratings, r_v(i) is the
%   estimate rating for user user_v(i) on item item_v(i);
load(trainFileName,'R','BETA','mu','bu','bi','P','Q','Y','W','C','Sk','alpha','opt');
[nUser,nItem] = size(R);
defaultRating = mu;         % default rating for tested entries on which
                            %    the trained model can not cover
testSize  = length(user_v);
r_v = defaultRating*ones(testSize,1);
I = (R~=BETA);

if testSize~=length(item_v)
    error('the length of user_v and item_v should be equal. Now length(user_v)=%d,\tlength(item_v)=',...
        length(user_v),length(item_v));
end

for id = 1:testSize
    u = user_v(id);
    i = item_v(id);
    if u>nUser || i>nItem 
        continue;
    end
    len_Nu = 0;
    if ~opt.classicalSVD
        Ru = find(I(u,:)); % Ru: R(u)
        Nu = Ru;           % Nu: N(u)
        len_Nu = length(Nu);
        [Rk_iu Rk_id]= intersect(Sk(i,:),Ru); % Rk_iu: R^k(i;u)
        Nk_iu = Rk_iu;                        % Nk_iu: N^k(i;u)
        Nk_id = Rk_id;                          
        len_Nk_iu = length(Nk_iu); 
        len_Rk_iu = length(Rk_iu);
    end
      % calculate the estimation for r_ui
    r_v(id) =  cal_rr_ui();
end
r_v = full(r_v);

    function r_val =  cal_rr_ui()
        % calculate the estimation for the rating r_ui
        %  rr_ui= mu + b_u + b_i + q_i'*(p_u + |N(u)|^(-0.5) * sum_{j\in N(u)}y_j)
        %       + alpha*|R^k(i;u)|^(-0.5) * sum_{j\in R^k(i;u)} (r_uj - b_uj)*w_ij
        %       + alpha*|N^k(i;u)|^(-0.5) * sum_{j\in N^k(i;u)} c_ij
        if ~opt.classicalSVD && len_Nu>0
            t1 = Q(:,i)'* (P(:,u) + weight(len_Nu)*sum(Y(:,Nu),2) );
        else
            t1 = Q(:,i)'* P(:,u);
        end
        t2 = 0;
        t3 = 0;        
        if ~opt.classicalSVD
            if len_Rk_iu
                t2 = alpha*weight(len_Rk_iu)*W(i,Rk_id)*(R(u,Rk_iu)'-(mu+bu(u)+bi(Rk_iu)));  
                    % note that W(i,Rk_id) is a row vector
            end
            if	len_Nk_iu
                t3 = alpha*weight(len_Nk_iu)*sum(C(i,Nk_id));
            end
        end
        r_val = mu + bu(u) + bi(i) + t1 + t2 + t3;
    end
end