function W = similarity(R,BETA,threshold)
% calculate Pearson correlation between two rows, the similarities (no
% co-ratings) can't be covered will be set 0;
% Inputs:
%  R, BETA:  raing matrix, with BETA (a real number) the missing ratings
%  threshold: optional, a positive integer indicate the significance
%  threshold (lower bound of the number of rating items), default value is
%  50;
% Outputs:
%  W: a symmtric matrix, W(i,j) indicate the Pearson correlation between
%   i-th row and j-th row; if there is nothing co-rated value, the
%   similarity will be set 0;
% Reference:
%  [1] Xiaoyuan Su, Taghi M. Khoshgoftaar, A Survey of Collaborative Filtering
%  Techniques. Advances in Artificial Intelligence. 2009.
%  [2] J. Herlocker, J. A. Konstan, J. Riedl, An empirical analysis of
%  design choices in neighborhood-based collaborative filtering
%  algorithms. Information Retrieval, 5, 287--310, 2002.

flag_significance_weight = 1; % use significance weighting
if nargin<=2
    threshold = 50;
end

[nUser nItem] = size(R);
W = zeros(nUser);
I = (R~=BETA);
[u] = userAverage(R,BETA);
R = (R-repmat(u,1,nItem)).*I;
for ii = 1:nUser-1
    % calculate the Person correlation between user ii and user jj, jj>ii
    
    if ~nnz(I(ii,:)) % user ii rated no item
        W(t,ii)=0;
    else
        t = ii+1:nUser;
        I2 = I(t,:).*repmat(I(ii,:),nUser-ii,1);
        R2 = repmat(R(ii,:),nUser-ii,1);
        norm_temp = sqrt(sum(R2.*R2.*I2,2).*sum(R(t,:).*R(t,:).*I2,2));
        W(t,ii) = sum(R2.*R(t,:).*I2,2)./(norm_temp+~norm_temp); 
                    % "+~norm_temp": deal with the case that norm_temp(jj)==0, for some jj
        if flag_significance_weight
            num_vec = sum(I2,2);
            W(t,ii) = min(num_vec/threshold,1).*W(t,ii);
        end
    end
    if ~mod(ii,10) %%%%%%
        fprintf('%d\n',ii);
    end
end
fprintf('\nfinished to calulate similarity between users.\n'); %%%%%
% set the values of W since W is symmetric
W = W + W'+ eye(nUser); % the elements on diagnal is set 1;