function [num_wrong_clip num_clip] = cal_wrong_clip_num(r,x,alpha,x_clip)
% calculate the number of entries with MAE enlarged after clipping on level
%   alpha
% Inputs: 
%  r: column vector, containg the real ratings;
%  x: a column vector with the same length as R, containing the predicted
%   rating;
%  alpha: a scalar indicating the clipping level, 0<=alpha<=0.5;
%  x_clip: Optional, a column vector with the same length as R, containing
%   the ratings after clipping of x; this is an alternative clipping style;
%   if this argument is set, ALPHA will be neglectted;
% Outputs:
%  num_wrong_clip: number of entries with MAE enlarged after clipping;
%  num_clip: number of entries which has been clipped;

num_clip = 0;
num_wrong_clip = 0;
if nargin<=3||isempty(x_clip)
    if alpha<=0
        return;
    end
    x_clip = round(x);
    I = abs(x-x_clip)<=alpha;
else % x_clip is input
    I = x~=x_clip; 
end

num_wrong_clip = nnz(abs(r(I)-x_clip(I))>abs(r(I)-x(I)));
num_clip = nnz(I);