function printFigure(h,varargin)
% format the figures according to a given parameters
% h: 
%   (1) a string indicating a matlab  figure file name (including the path) (or a
%        figure handle (support in future version) );
%   (2) a string cell array containing more than one strings, with each one indicating a matlab figure file
%        name;
%        In this case, if user do not set the 'Position' argument, the
%        position of all the matlab figures will be set as the position of
%        the given first figure;
%        otherwise, if user set the `Position' argument, the position of
%        all the figures will be set as the given argument.
% varargin: parameters
%   varargin{2*i-1} indicates the parameter name;
%   varargin{2*i} indicates the parameter value; i = 1, 2, ...
%   'Position': default  [0 0 4*72 3*72]
%   'Format': default  fig'-depsc2' (eps Level 2 color);
%   'FontName': font name of the figure
%   'FontSize': default 12
%   'LegendFontSize': default 10, fontsize of the legend (if exist)
%   'LegendBox': default 'on'; whether show the box surrounded the legend; 

if mod(nargin,2)~=1 % the first input is h
    error('the arguments should be set in name-value pairs.');
end

% get the arguments
opt = struct();
flag_setPos = 0;
if nargin>1
    opt = assignStruct(opt,varargin(1:2:end),varargin(2:2:end)); 
    flag_setPos = isfield(opt,'Position') && ~isempty(opt.Position);
end
    % assign the options
opt = completeArg(opt, {'Position','Format','FontName','FontSize','LegendFontSize','LegendBox'},...
    {[0 0 4*72 3*72], '-depsc2', 'Arial',12,10,'on'});
    
if ~iscell(h)
    printFigure0(h,opt);
else % h is a string cell array
    % get the 'Position' setting
    if ~flag_setPos
        % get the Position of the first figure    
        h1 = openfig(h{1});        
        Pos_v = get(h1,'Position');
        opt.Position = Pos_v;
        close(h1);
    end

    for ii=1:length(h)        
        printFigure0(h{ii},opt);
    end
end

end % end the main function


function printFigure0(h,opt)
% print figure indicated by the matlab figure file h1
% h1: a string 
% opt: a structure containing parameters

h_fig = openfig(h);  
  % set the size of the figure 
set(h_fig,'Position',opt.Position);

    % set  paperposition
blank_c = min(30,opt.Position(3)*0.06);
paperPosition_v = [blank_c blank_c opt.Position(3:4)*0.9]; % remain a certain blank    
set(h_fig,'PaperPositionMode','manual');
set(h_fig,'PaperUnits','points');
set(h_fig,'PaperPosition',paperPosition_v);
set(h_fig,'PaperSize', opt.Position(3:4)); % set a reasonble papersize and paperposition
  
  % set the font name and  font size of the figure
set(gca,'FontName',opt.FontName);
set(gca,'FontSize',opt.FontSize);

  % set the legned font size and legend box
h_legend = findobj(h_fig,'Type','axes','Tag','legend'); % get the handle of the legend object
if ~isempty(h_legend) && ishandle(h_legend)
    set(h_legend,'FontName',opt.FontName); % set the legend font name
    set(h_legend,'FontSize',opt.LegendFontSize);
    set(h_legend,'Box',opt.LegendBox);
end

 % save the figure 
[pathstr name] = fileparts(h);
fileName_str = [pathstr filesep name '_01'];
    % append an extra string to distinct with the original file
fileName_fig = [fileName_str '.fig'];
fileName_eps = [fileName_str '.eps'];
saveas(h_fig,fileName_fig);
if strcmpi(opt.Format,'-depsc2')
    %print(h_fig,'-depsc2','-loose',fileName_eps); % save as eps
    print(h_fig,'-depsc2',fileName_eps); % save as eps
       
else
    print(h_fig,opt.Format,fileName_eps); % save as eps
end
close(h_fig); % delete the figure

end