function r_clip_v = clip(r_v,index,index_MAE,pad_MAE)
% clip part of the ratings to integers

% Inputs:
% r_v: a columm vecter containg ratings
% index: a column vector with the same length as r_v, containing confidence
%   measures for each ratings;
% index_MAE: a matrix with two columns, indicating the relationship between
%   the confidece index and MAE; the first column is ascendingly ordered, 
%   the second column is the MAE to be refered, E.g.
%   index_MAE = [ .0109 .50;
%                 .0122 .65;
%                 .0187 .70;
%                ...
%                 .0330 .90 ];
%  means if a measure index for an predicted rating lie in (-Inf,.0109],
%  its expected MAE is .50;  (.0109 .0122] the expected MAE is .65, etc;
%  pad_MAE, Optional, a scalar located in in [0,0.5), the 2nd column of index_MAE
%    will add to this quantities before operating clips; default 0;
% Outputs: 
%  r_clip_v: a column vector with the same length as r_v, containing the
%    ratings after clipping, the ratings unsatisfying the clipping
%    condition will remain the same as before; 

if nargin<=3
    pad_MAE = 0;
end
sizeBag = size(index_MAE,1);
r_clip_v = r_v;

[num_balls indices_bags]= falltoBags(index,index_MAE(:,1));
for ii=1:sizeBag
    id_v = find(indices_bags == ii);
    alpha = min(index_MAE(ii,2)+pad_MAE,1-index_MAE(ii,2)-pad_MAE);
    if alpha<=0
        continue;
    end
    r_clip_v(id_v) = clip_0(r_v(id_v),alpha);    
end

end

function y = clip_0(x,alpha)
% Inputs: 
%  x: a column vector;
%  alpha: a scalar, 0<=alpha<=0.5;
% Outputs:
%  y: the column vector after clipped, the same length as x;
%  y(i) = round(x(i)), if |x(i)-round(x(i))|<=alpha;
%            x(i),     otherwise;
y = x;
if alpha<=0
    return;
end
z = round(x);
I = abs(x-z)<=alpha;
y(I) = z(I);
end


