function [white gray black blue]=white_gray_black_blue_sheep(id_v,act_v,measure_v,arg)
% seperate the entries to be predicted into White sheep, Grey sheep, Black
%   sheep and Blue sheep;
% Inputs:
%  id_v: a column vector, containing the IDs for the sheep;
%  act_v: a column vector with same length as ID_V, containing the
%   activities for each entry (sheep);
%  measure_v: a column vector with same length as ACT_V, containing the
%    confidence measure (e.g. relatedness) for each entry (sheep);
%  arg.weight_v: Optional,a 3*1 column vector, containg the percentages
%    (excluded Blue sheep ) of White, Grey and Black sheep satisfying
%    sum(weight_v)=1; weight_v(ii)>=0; ii=1,2,3; 
%  arg.blue_activity: Optional, sheep with activity less than this
%    BLUE_ACTIVITY will be considered as blue sheep;
%  arg.indexMode: Optional, 'ascend' or 'descend': indicating the value of
%    confidence measure (e.g. relatedness) is ascending or descending from
%    White Sheep to Black Sheep; 
% Outputs:
%  while, gray, black, blue: four column vectors, containing the IDs of
%    White, Grey, Black, and Blue sheep respectively;

getArg(arg,'weight_v',[0.15 0.70 0.15]);
getArg(arg,'blue_activity',5);
getArg(arg,'indexMode','descend');

% Identify the Blue sheep
blue = id_v(act_v<=blue_activity);

% Identify the White, Grey and Black sheep
act_id_v = find(act_v>blue_activity); % vector of IDs of active sheep;
len_act_v = length(act_id_v);

%[act_v_sort act_id_sort] = sort(measure_v(act_id_v),'ascend');
[act_v_sort act_id_sort] = sort(measure_v(act_id_v),indexMode);

% if nargin>=6&&~isempty(good_bad_line) % good_bad_line is set
%     num_act_sheep = zeros(3,1);
%     num_act_sheep(1) = nnz(measure_v(act_id_v)<=good_bad_line(1)); % number of white sheep
%     num_act_sheep(3) = nnz(measure_v(act_id_v)>good_bad_line(2));  % number of black sheep
% else
%     num_act_sheep = floor(weight_v*len_act_v);     
% end
num_act_sheep = floor(weight_v*len_act_v);     
num_act_sheep(2) = len_act_v - num_act_sheep(1) - num_act_sheep(3); % number of gray sheeps

white = [];
gray = [];
black = [];
if num_act_sheep(1)
    white = id_v(act_id_v(act_id_sort(1:num_act_sheep(1))));
end
if num_act_sheep(2)
    gray = id_v(act_id_v(act_id_sort(num_act_sheep(1)+1:num_act_sheep(1)+num_act_sheep(2))));
end
if num_act_sheep(3)
    black = id_v(act_id_v(act_id_sort(num_act_sheep(1)+num_act_sheep(2)+1: len_act_v)));
end