function [d mae_T1, mae_T2 ]= diff_mae(rel_v,Test,Predict,arg)
% calculate the difference of MAE matric
% Input:
%   rel_v: relatedness values;
%   Test: matrix of true observed ratings;
%   Predict: matrix of predicted ratings by a certain CF method, with the
%      same size as Test; 
%   arg: a struct, Optional, possible fields:
%     .BETA: the missing rating of Test and Predict are filled with BETA;
%       default 0;
%     .I, .J: two column vectors of the same size, (I(i),J(i)) indicating
%        the i-th tested user-item pairs; in default [I, J] = find(Test~=arg.BETA);
% Outputs:
%   d: diff_mae
%   mae_T1: MAE(Test1)
%   mae_T2: MAE(Test2), see the following description for details;
%
% Description: 
%            diff_mae = MAE(Test1) - MAE(Test2) 
% where Test is divided into Test1 and Test2, according the relatedness
% metric, the user-items pairs with the highest relatedness are made up of
% Test1, others are made up of Test2. 

% default parameters
if nargin<=3 || ~isfield(arg,'BETA') || isempty(arg.BETA)
    arg.BETA = 0;
end
if nargin<=3 || ~isfield(arg,'I') || isempty(arg.I)
    [arg.I arg.J] = find(Test~=arg.BETA);
    if length(rel_v)~=length(arg.I)
        error('row and column indices of the Test set is needed.');
    end
end
    
if length(rel_v)~=length(arg.I)
    error('length of rel_v and arg.I should be equal.');    
end
if size(Test,1)~=size(Predict,1) || size(Test,2)~=size(Predict,2)
    error('size of the matrix Test and Predict should coincide.');    
end

[rel_v ind] = sort(rel_v,'descend');
len = length(ind);
len_half = round(len/2);
ind_mat = sub2ind( size(Test), arg.I(ind), arg.J(ind));
val_diff_v = abs(Test(ind_mat) - Predict(ind_mat));
mae_T1 = sum(val_diff_v(1:len_half)) / len_half;    
mae_T2 = 0;

len_half2 = len-len_half;
if len_half2 >0
    mae_T2 = sum(val_diff_v(len_half+1:len)) / len_half2;    
end

d = mae_T2- mae_T1;

end
 