function [num_balls indices_bags bags num_virtualball]= distribute(balls,bags,n,coverage,cover_mode)
% show the distribution of the values in x
% Usage:
%   [num_balls indices_bags] = distribute(x,bags); % the sections are given by bags
%   [num_balls indices_bags bags]= distribute(x,[],n); % part n sections
% Inputs:
%   balls: a vector 
%   bags: the sections to receive the values of entries of x
%   n: part n sections
%   coverage: a scalar located in [0,1] percent of the counted the balls
%   cover_mode: 'left': choose the balls of left  part (small) 
%               'right': choose the balls of right part (big)
%               'center': choose the center (not too big nor too small)
%               balls
% Outputs:
%   num_balls: a (column) vector, same size as bags, num_balls[i]: the number of elements
%     of x lie in the section (bags(i-1), bags(i) ], bags(0) is defined
%     as minums infinity
%   indices_bags: a (column) vector, same size as x, indices_bag(i) indicate 
%     the bag which the i-th ball belongs to; all the (uncovered) remaining balls will
%     be indicated into a virtual bag: the length(bags)+1 - th bag
%   bags: indicate the N bags in the usage
%       [num_balls indices_bags bags]= distribute(x,[],n)
%   num_virtualball: number of balls falling into the virtual bag

num_balls = []; indices_bags=[]; 
if isempty(balls)
    return
end

if size(balls,2)>1
    balls = balls'; % transform to a column vector;    
end
if size(bags,2)>1
    bags = bags';
end

if nargin<=2
    [num_balls indices_bags] = falltoBags(balls,bags);
    return;
end

% now nargin>=3
if nargin<=3
    coverage = 0.85; 
end
if nargin<=4
    cover_mode = 'left';
end
% choose a proper section
median_b = median(balls);
% s = std(balls);
% i_ball = find(abs(balls-median_b)/s<0.005);
[y ind] = sort(abs(balls-median_b));
len_ind = length(ind);

switch lower(cover_mode)
    case {'left'}
        i_ball_l = 1;
        i_ball_r = max(round(len_ind*coverage),1);
    case {'right'}
        i_ball_l = max(round(len_ind*(1-coverage)),1);
        i_ball_r = len_ind;
    otherwise
        half_per = (1-coverage)/2;
        i_ball_l = max(round(len_ind*half_per),1);
        i_ball_r = max(round(len_ind*(1-half_per)),1);
end
i_ball = ind(i_ball_l:i_ball_r);

l = min(balls(i_ball));
r = max(balls(i_ball));
if isempty(i_ball) || l>=r ||length(balls)<=3
    l = min(balls);
    r = max(balls);
end
bit = floor(log10(abs(r)));
N = 10^(bit-1);
r1 = ceil(r/N)*N;
l1 = floor(l/N)*N;

bags = linspace(l1,r1,n)';
[num_balls indices_bags] = falltoBags(balls,bags);
num_virtualball = length(balls) - sum(num_balls);