function [h_bar h_line h_horizontal_line_v h_left_axis_out h_right_axis_out] = draw_bar_line(x_v, varargin)
% draw bars and 2-D line 

% Inputs:
%   x_v: column vector containing values of x-axis;
%   varargin: a cell array containing arguments name and followed by arguments
%       value pair by pair, such as {'y_left_v',[3 7 8], 'x_label','coherece'};
%     Possible argument names:
%     * 'y_left_v': indicates a column vector with the same length as x_v, containing
%       values of bars;
%     * 'y_right_v': indicates a column vector with the same length as x_v,
%        containing values of lines;
%     * 'bar_prop_cell': indicates a cell array containing the properties
%       of bars for instance the properties may be: width, style, or 
%       'bar_color', etc;
%     * 'line_prop_cell': indicates a cell array containing the properties
%       of the line;
%     * 'x_range': indicates a 2*1 vector, range of the x-axis
%     * 'x_label': indicates the label of the x-axis;
%     * 'y_left_label': indicates the label of left y-axis
%     * 'y_right_label': indicates the label of right y-axis
%     * 'horizontal_line_height_v': indicates a vector, with this arguments,
%       the function will draw horizontal lines with the height indicated
%       by each entries of this arguments, (fix the height according to the
%       right y-axis) 
%     * 'horizontal_line_prop_cell': indicates a cell array, with the same
%       lenght as 'horizontal_line_height_v', indicating properties of the
%       horizontal lines;

% Outputs:
%   h_bar: handle of the bar,set [] if no bar is drawn;
%   h_line: handle of the line, set [] if no line is drawn;
%   h_horizontal_line_v: a column vector containing hanles of the
%      horizontal lines, set [] if no horizontal line is drawn;
%   h_left_axis_out: handle of the axis with y-axis on the left
%   h_right_axis_out: handle of the axis with y-axis on the right (top layer)

% 0. Initiation
argument_cell = {'y_left_v','y_right_v','bar_prop_cell','line_prop_cell','x_range','x_label','y_left_label',...
    'y_right_label','horizontal_line_height_v','horizontal_line_prop_cell'};
[y_left_v, y_right_v,bar_prop_cell,line_prop_cell,x_range,x_label,y_left_label,y_right_label,...\
    horizontal_line_height_v,horizontal_line_prop_cell] = getArgument(varargin,argument_cell);

flag_ishold = ishold;
h_bar = []; h_line = []; h_horizontal_line_v = [];
color_cell = {'r','g','b','c','y','m','k',[.3 .5 .7],[.5 .3 .7],[.7 .3 .5],[.3 .7 .5],[.7 .5 .3],[.5 .7 .3]};

global flag_barPlot h_left_axis h_right_axis

if isempty(flag_barPlot)||~flag_ishold % if the hold state is off, set the flag_barPlot 0
    flag_barPlot = 0; % indicate whether bars has been plot in current figure
end

% 0. plot left and right axes
if isempty(h_left_axis)||isempty(h_right_axis)
    h_left_axis = axes();
    h_right_axis = axes('Position',get(h_left_axis,'Position'));
    set(h_right_axis,'YAxisLocation','right','Color','none','Layer','top'); % set the h_right_axis right and top layer
end
h_left_axis_out = h_left_axis;
h_right_axis_out = h_right_axis;
    % set XLim
if ~isempty(x_range)
    set(h_left_axis,'XLim',x_range);
    set(h_right_axis,'XLim',get(h_left_axis,'XLim'));
end
    % set box off
if ~isempty(h_left_axis)    
    box(h_left_axis,'off'); 
end
if ~isempty(h_right_axis)
    box(h_right_axis,'off');
end
    
% 1. plot bar graph: x_v -- y_left_v
if ~isempty(y_left_v)   
    if ~isempty(bar_prop_cell)        
        h_bar = bar(h_left_axis,x_v,y_left_v,bar_prop_cell{:});
    else
        h_bar = bar(h_left_axis,x_v,y_left_v);
    end
    flag_barPlot = 1; 
    % set the label of left y-axis
    if ~isempty(y_left_label)
       ylabel(h_left_axis,y_left_label,'fontsize',11);
    end

end 


    %set(h_left_axis,'Layer','top');
     
% 2. plot the line
    % 2.1 set the currenct axes h_right_axis
%  if flag_barPlot  
%     h_right_axis = axes('Position',get(h_left_axis,'Position'));
% else
%     h_right_axis = gca;
% end

    % 2.2 set the hold state
if flag_barPlot 
    hold on
end
    % 2.3 plot the line
%flag_plot_MAE_line = 0;   % indicate whether the line has been depicted 
if ~isempty(y_right_v)
    if isempty(line_prop_cell)
        % randomly choose a color
        i_color = randi(length(color_cell));
        h_line = plot(h_right_axis,x_v,y_right_v,'linewidth',2,'Color',color_cell{i_color});        
    else
        h_line = plot(h_right_axis,x_v,y_right_v,line_prop_cell{:});        
    end
    %flag_plot_MAE_line = 1;
end
    % 2.4 plot horizontal lines
if ~isempty(horizontal_line_height_v)
    len_horizontal_line = length(horizontal_line_height_v);
    h_horizontal_line_v = zeros(len_horizontal_line,1);
    for ii = 1:len_horizontal_line
        if isempty(horizontal_line_prop_cell)
            i_color = randi(length(color_cell));
            h_horizontal_line_v(ii) = plot(h_right_axis,x_range,horizontal_line_height_v(ii)*[1,1],'Color',color_cell{i_color}); 
        else
            h_horizontal_line_v(ii) = plot(h_right_axis,x_range,horizontal_line_height_v(ii)*[1,1],horizontal_line_prop_cell{ii}{:});
        end
    end
end

   % 2.5 set YTick
if ~isempty(horizontal_line_height_v)
    y_tick = get(gca,'YTick');        
    y_tick = sort([y_tick horizontal_line_height_v']);
    % exclude the ticks located too near
    radius = ((max(y_tick)-min(y_tick))/length(y_tick))/4;  
    p = 1;
    while p<=length(tick)-1
        if y_tick(p+1)-y_tick(p)<radius
            y_tick(p+1) = [];
        else
            p = p+1;
        end
    end
    set(h_right_axis,'YTick',y_tick);
end

    % 2.7 set xlabel and ylabel (right axis)
if ~isempty(x_label)    
    xlabel(h_right_axis,x_label,'fontsize',11);
end
if ~isempty(y_right_label)
    ylabel(h_right_axis,y_right_label,'fontsize',11);
end
% %     % 2.8 set box of h_left_axis off
% % if flag_barPlot
% %     box(h_left_axis,'off');  
% % end
    % 2.9 reset the hold state as original
if ~flag_ishold
    hold off
end
    

end % end of the function