function fwritef(fid,varargin)
%write some variables to a file 
%Input Arguments:
%   fid: the handle of the file
%   varargin: in the form: {labelOfVar1,var1,'format1', labelOfVar2, var2,'format2',...}
%           the default format of variables which type is 'double' is
%           '%8.4f\t'

%var=[];
%format='';type='';nm='';
for i=1:3:nargin-1
    nm=varargin{i};
    var=varargin{i+1};
    format=varargin{i+2};
        
    % print variable name
    if ~isempty(nm) && (ischar(var)||isnumeric(var))
        fprintf(fid,'%s',nm);
        fprintf(fid,'\t');
    end
    
        % construct a temparary varable NM1: add a tab space before NM
    if iscell(var)
        nm1 = sprintf('\t');
        if isempty(strtrim(nm))
            nm1 = sprintf('\t%s',nm);
        end
    end
    
    %print variable values
    if ischar(var)
        if strcmp(format,'')
            format= '%s';
        end
        fprintf(fid,format,var);
        fprintf(fid,'\n');       
    elseif isnumeric(var)
        if isempty(format)
            if isinteger(var)
                format = '%d\t';
            elseif isreal(var)
                format= '%8.4f\t';
            else % iscomplex
                format = '%.3f + %.3fi\t';
            end
        end
        
        for dim=1:size(var,1)
            if isreal(var)
                fprintf(fid,format,var(dim,:));
            else                
                fprintf(fid,format,real(var(dim,:)),imag(var(dim,:)));
            end
            fprintf(fid,'\n');
        end
    elseif isstruct(var)
        fn = fieldnames(var);        
        if length(var)==1
            % put out the names and values of each fields            
            for ii=1:length(fn)
                nm1 = sprintf('%s.%s',nm,fn{ii});                    
                fprintf(fid,'%s\t= ',nm1);
                if isstruct(var.(fn{ii})) || iscell(var.(fn{ii}))
                    fprintf(fid,'\n');
                    nm1 = sprintf('\t%s',nm1);                    
                    fwritef(fid,nm1,var.(fn{ii}),'');
                else                    
                    fwritef(fid,'',var.(fn{ii}),'');                     
                end                
            end
        else
            size_v = size(var);
            n = length(size_v);
            if n==2 && (size_v(1)==1 || size_v(2)==1) % var is a one-dimensional struct array 
                % reset N and SIVE_V
                n=1;
                size_v = length(var);
            end
            ind = 0;                        
            while 1
                v = decimal2general(size_v,ind);
                if v(n)>=size_v(n) % size_v: from left to right: low dight --> high digit
                    break;
                end
                % put out the values of each fields                
                for ii=1:length(fn)                                        
                    nm1 = sprintf('%s(',nm);
                    if n>1
                        nm1 = strcat(nm1,sprintf('%d,',v(1:n-1)+1));
                    end
                    nm1 = strcat(nm1,sprintf('%d)',v(n)+1),sprintf('.%s',fn{ii}));                    
                    fprintf(fid,'%s\t= ',nm1);
                    if isstruct(var(ind+1).(fn{ii})) || iscell(var(ind+1).(fn{ii}))
                        fprintf(fid,'\n');
                        nm1 = sprintf('\t%s',nm1);
                        fwritef(fid,nm1,var(ind+1).(fn{ii}),'');
                    else
                        fwritef(fid,'',var(ind+1).(fn{ii}),'');                     
                    end
                end
                ind = ind + 1;
            end
        end
    elseif iscell(var)        
        if length(var)==1
            % put out the value of the cell            
            if ~isempty(strtrim(nm))
                fprintf(fid,'%s =\n',nm);
            else
                fprintf(fid,'%s',nm);
            end
            fwritef(fid,nm1,var{1},'');            
        else
            size_v = size(var);
            n = length(size_v);
            if n==2 && (size_v(1)==1 || size_v(2)==1) % var is a one-dimensional cell array 
                % reset N and SIVE_V
                n=1;
                size_v = length(var);
            end
            ind = 0;                        
            while 1                
                v = decimal2general(size_v,ind);
                if v(n)>=size_v(n)
                    break;
                end
                % put out the values of each cell
                fprintf(fid,'%s{',nm);
                if n>1
                    fprintf(fid,'%d,',v(1:n-1)+1);
                end
                fprintf(fid,'%d} = \n',v(n)+1);                
                fwritef(fid,nm1,var{ind+1},''); 
                ind = ind + 1;
            end
        end
        
    end
end
end % end of the function fwritef()

function  v = decimal2general(size_v,ind)
% transfrom a decimal integer to a general digit
%  Inputs: 
%   size_v: a vector consists positive integers, indicating the n-ary digits
%      e.g. size_v(i) = 3 means 3-1 = 2  is the maximum number for the i-th digits
%  Outputs:
%   v: a vector with the same length as SIVE_V consisting nonnegative
%       integers
n = length(size_v);
v = zeros(n,1);
base = prod(size_v);
for ii=n:-1:1 %  ii iterates from the high (right) digit to low (left) digit    
    base = base/size_v(ii);    
    v(ii) = floor(ind/base);
    ind = ind - v(ii)*base;    
end    
end