function addFileRecord(B,arg)
% set file record
%
% Inputs
%  B: a cell array of strings, the columns of B corresponding the columns
%       of F
%  arg.force: 1: if a record with the given key already exist, delete the
%         orignal record, 0: do not add the new record; default 0;
%
% 0. download data F

% set argument arg
if nargin<2 || ~isfield(arg,'force') || isempty(arg.force)
    arg.force = 0;
end

dataFile = getconstant('fileInf');
if exist(dataFile,'file')
    load(dataFile,'F'); % load file information cell matrix F
else
    F = cell(0);
end

% 1. pre-processing of B

  % 1.1 trim the leading and tailing  filesep ('/' or '\') and space of  the dirs (the first column of  B)
B(:,1)  = cellfun(@mytrim, B(:,1),'UniformOutput',false);
  % 1.2 make the key fileds (the second column of B) lower case
B(:,2) = cellfun(@lower,B(:,2),'UniformOutput',false);  

% 2. append cell matrix B to cell matrix F
idrow = size(F,1)+1;
[rowB colB]= size(B);
for ii=1:rowB
    id=findFileRecord(B{ii,2});
    if ~isempty(id) % the file key had always exist
        if ~arg.force
            warning('record %d is not added since the key %s has exist.',ii,B{ii,2});
            continue;
        else
              % delete the original record
              delFileRecord(B{ii,2});
        end
    end       
    % add the new file record
    F(idrow,1:colB) = B(ii,:);
    idrow = idrow+1;
end
% 3. update F of the dataFile
save(dataFile,'F');
end

function str = mytrim(str)
% trim the leading and trailing space or filesep ('\' or '/') of a string
str = strtrim(str);
if isempty(str)
    return
end
if str(1) == filesep
    str(1) = [];
end
if  ~isempty(str) && str(length(str)) == filesep
   str(length(str)) =[]; 
end
end