function C=merge_sparse_matrix(A,B)
% merge two sparse matrices A and B
%
% Inputs:
%  A, B: two sparse matrices
% Outputs:
%  C: the merged matrix, if A, B contain different values at a commen
%     location (i,j), then C(i,j) would be set B(i,j)

[a1 a2]=size(A);
[b1 b2]=size(B);
c1 = max(a1,b1);
c2 = max(a2,b2); % [c1, c2] would be the size of C


if a1<c1 || a2<c2 
    % concatenate the zero elements to A to ensure size(A) equal size(C)
    A = [A sparse(a1,c2-a2);
             sparse(c1-a1,c2)];
end
if b1<c1 || b2<c2
    % concatenate the zero elements to B to ensure size(B) equal size(C)
    B = [B sparse(b1,c2-b2);
             sparse(c1-b1,c2)];
end

C=A; % assign A to C

C(B~=0) = B(B~=0); % assign B to C

end