function [Train Quiz] = quiz(R,sampleRate)
% divide the base set (original training set) into a train set and a quiz set

% Inputs:
%   R: base set, a sparse matrix;
%   sampleRate: optional, sampleRate is the ratio between the number of
%     sampled entries and the number of the known entris in the base set
%     R; i.e. sampleRate = nnz(Quiz)/nnz(R);  
%	  the entries in the quiz set will be sampled randomly for each user,
%	  i.e. for each user sampleRate is nearly equal to
%	  nnz(Quiz(user,:))/nnz(R(user,:)) 
% Outputs: 
%   Train: a sparse rating matrix for training
%   Quiz: a sparse rating matrix for quiz
  
if nargin<=1
    sampleRate = 0.1; % default sample rate
end
if sampleRate>=1
    sampleRate = round(sampleRate);
    flag_contant_sample = 1; % constant sampling sampleRate entries from each user with actitivity >= 2*sampleRate;
else
    flag_contant_sample = 0; 
end

[nUser nItem] = size(R);
Train = sparse(nUser,nItem);
Quiz = sparse(nUser,nItem);

for ii=1:nUser
    %%%
    if mod(ii,500)==1 
        fprintf('%d\n',ii);
    end 
    %%%
    item_v = find(R(ii,:));
    len_item_v = length(item_v);    
    if ~flag_contant_sample
        p = ceil(len_item_v*sampleRate);
    else % constant sampling sampleRate entries from each user
% % %         if len_item_v < 2*sampleRate
% % %             p = 0;
% % %         else
% % %             p = sampleRate;
% % %         end        
        p = min(sampleRate,len_item_v);
    end
    item_v_id = randperm(len_item_v);
    if p>0    
        Quiz(ii,item_v(item_v_id(1:p))) = R(ii,item_v(item_v_id(1:p)));
    end
    if p<len_item_v
        Train(ii,item_v(item_v_id(p+1:len_item_v)))=R(ii,item_v(item_v_id(p+1:len_item_v)));
    end
end