function [x1 y1] = sortToBags(x,y,bag_capacity,fun_x,fun_y,sort_mode)
% Pack x and y to bags, with each bag contain constant number of balls; the
% elements of x and y are viewed as one-to-one, they will be first be
% sorted according x, then the elements of x and y in each bags will be
% operated by fun_x and fun_y, the results will be stored in x1 and y1,
% respectively;  

% Inputs:
% x, y: two vectors with the same length;
% bag_capcity: a positive integer indicate the bag capacity;
% fun_x, fun_y: two function handles which operates on elements of x and y
%   in each bags respectively; the corresponding function should accept one
%   input of vector; 
% sort_mode: optional, 
%       'ascend': sort the elements of x ascendingly, default value;
%       'descend': sort the elements of y descendingly;
% Outputs:
%  x1, y1: two column vectors with the same length as
%    ceil(length(x)/bag_capacity); 


if nargin<=5
    sort_mode='ascend';
end
nball = length(x);
if nball~=length(y)
    error('the length of x and y should be equal.');
end
bag_num = ceil(nball/bag_capacity); % section/bags number
[x_sort x_id] = sort(x,sort_mode);
y_sort = y(x_id);
x1 = zeros(bag_num,1);
y1 = zeros(bag_num,1);
for ii=1:bag_num
    lp = (ii-1)*bag_capacity+1;
    if ii<bag_num
        up = ii*bag_capacity;
    else % ii==bag_num
        up = nball;
    end
    x1(ii) = fun_x(x_sort(lp:up));
    y1(ii) = fun_y(y_sort(lp:up));
end

end