function fun = makefun_gamma(arg)
%  generate a function with given parameter values of function adapative_gamma()
% Input:
%  arg: a struct, at least contain the field names
%   .n1 .n2 .r0, .r1, .r2
%    with each field value a scalar
% Output:
%  fun: a function handle with the format
%         gamma = fun(n)
%     where n: number  of users (or the items) the matrix where to search
%     the local community;
%       gamma:  a scalar located in (0,1), indicating the number of the users
%      or items to search: n*gamma.

fun = @adaptive_gamma;
    
    function gamma = adaptive_gamma(n)
        rr0 = arg.r0;
        rr1 = arg.r1;   % rr0, rr1, rr2 in (0,1), rr2<rr1<rr0
        n1  = arg.n1; 
        rr2 = arg.r2;
        n2  = arg.n2; 
           % MAKE SURE THAT rr2,n2 satisfies that n2*rr2>rr1*n1.

        p = log(rr1/rr2)/log((n1+1)/(n2+1));
        alpha = rr1*(n1+1)^(-p);
        if n<=n1
            gamma =  (rr1-rr0)/n1*n + rr0; 
                    % a line pass through the two points (0, rr0), (n1, rr1)            
        else
            gamma = alpha*(n+1).^p;
                    % alpha,p satisfies that the curve pass through the two points:
                    %  (n1, rr1), (n2, rr2);
        end
     end % end function adaptive_gamma()

end