function fun = makefun_kappa(coef)
% make function of adaptive_kappa() with different coefficient
%   fun() = coef * adaptive_kappa()
% Input: 
%  coef: a positive scalar;
%  Output:
% fun:   a function handle 


fun = @my_adaptive_kappa;

    function  kappa = my_adaptive_kappa(n)
        kappa = coef*(adaptive_kappa(n));
    end

end

function kappa = adaptive_kappa(n)
% calculate kappa 
% Input:
%   n: the dimension of the solution space

% Description:
%       min     lambda*||x||_1 + 1/2||Ax-y||_2^2
%       s.t.    w_i*|x_i| <= kappa,
%   where A in R^{m,n}, w_i>=0 is scale factor, i = 1,...,n;
%   lambda>0, kappa>0 are given parameters. 

kappa = max(2/n,1/(3*sqrt(n)) );
end % end of adative_kappa() 