function [w,actSet] = pearson_kCovariant(A,b,k,aveR)
% find k columns of A that most similar with vector b under Pearson
%   similarity measure

%Inputs
%	A    : a  matrix with size [p q].
%	b    : column vector with length p.
%   k    : choose k columns of A, most related with vector b; 
%   aveR : column vector with length q+1, average rating for the q+1  users (or items)
%          aveR(1:q) are the average rating for the users (or items)
%          corresponding the q columns of A, while aveR(q+1) is the
%          average rating for the user (or item) corresponding to the
%          rating vector b;
% Outputs
%	w    : k ordered similarities of the between each selected
%          columns with vector b
%   activeSet: a vecter consists indices of selected columns
%   inform   :        inform.residual: L2 norm of the residual at termination (with unitized data!); 
%                     inform.lambda: lambda at termination (with unitized data!);
%                     inform.fval:   objective function value at termination (with unitized data!) 
%                     inform.solutionNorm: 1-norm of the solution (with unitized data!)
[p q] = size(A);
if isempty(A)||isempty(b)
    w = 0;
    actSet = [];
    return;
end

BETA = 0; % the missing rating of A are filled with BETA
A1 = A - ones(p,1)*aveR(1:q)';
b1 = b - aveR(q+1);
epsilon = 1.0E-6;
w = zeros(q,1);
for ii=1:q
    ind = abs(A(:,ii)-BETA)>epsilon;
    if nnz(ind)>0
        w(ii) = sum(A1(ind,ii).*b1(ind))/(norm(A1(ind,ii))*norm(b1(ind)));    
    end
end
[w iw]= sort(w,'descend');
w = w(1:k);
actSet = iw(1:k);
end
