function [rel_v grade_v inform_tv]= rel_testset(dataFile,I,J,arg)
% calculate the relatedness of user-item pairs on a given  test dataset
% Inputs:
%  datafile: data file name, containing a matrix 'Train' as the training
%    rating matrix; 
%  I,J: two vectors with the same length, consisting of the indices of
%     users and items to calculate the relatedness values
%  arg: Optional, a structure for setting arguments; see activeSubmatrix
%   for detail; here, arg may has an appended field (Optional),
%       arg.dataFileInf: name of the file containing variable:
%           ave_rating_item, ave_rating_user, which is the average rating
%           of users and items, only used for arg.machine is set 'Pearson'
%       arg.predictFile: name of the mat file containing a matrix 'Predict',
%            which is made of the predicted missing ratings;
%       arg.n1, n2, r0, r1, r2: parameters for function makefun_gamma()
%       arg.kappa_alpha_coef: parameter for function makefun_kappa() 
%       arg.kappa_beta_coef:  parameter for function makefun_kappa()
% Outputs:
%  rel_v: a column vector consisting of the calculated relatedness values
%  grade_v: a column vector consisting of the predicted ratings
%  inform_tv: a structure array (vector) at least contains the fields as
%     indicated in predictOneElement.m

len_I = length(I);
flag_output_inform = nargout>=3; % whether need to putout the 3rd parameter: inform_tv

% initialize grade_v
grade_v = zeros(len_I,1);
rel_v = zeros(len_I,1);
%%inform_tv = struct();
% calculate the reltedness values

% initialize inform_tv
[grade_v(len_I) inform_tv(len_I)]= predictOneElement(dataFile,I(len_I),J(len_I),arg);    
rel_v(len_I) = inform_tv(len_I).relatedness;
if matlabpool('size') == 0
    matlabpool('open');
end

parfor k= 1:(len_I-1)
 %%for k= 1:len_I-1
    if flag_output_inform       
        [grade_v(k) inform_tv(k)]= predictOneElement(dataFile,I(k),J(k),arg);            
        rel_v(k) = inform_tv(k).relatedness;        
    else
        [grade_v(k) inform]= predictOneElement(dataFile,I(k),J(k),arg);    
        rel_v(k) = inform.relatedness;
    end        
end
if matlabpool('size') > 0
    matlabpool('close');
end
end
