function [acc_t]=cal_precision_rel(R,user_v,item_v,rate_v,rel_v,k,rel_level,goodEntryMark_recommend,goodEntryMark_acc,flag_comprehensive)
% calculate the precisions under various relatedness levels
%
% Inputs:
% R: the rating matrix, a sparse matrix containg at least the real ratings of
%   tested entries; 
% user_v, item_v: two column vectors indexing tested users corresponding items
% rate_v, rel_v: two column vectors with the same length as user_v and
%   item_v, indicating the predicted ratings and corresponding relatedness;
% k: an integer, top-k recommendation
% rel_level: a column vector, containing levels of relatedness, cal_precision_rel ()
%    function calculate the recommendation precision under various levels
%    of relatedness;
%  goodEntryMark_recommend: a scalar, for a certain user, items with predicted ratings not
%     less than this scalar are viewed as prefered ones 
%  goodEntryMark_acc: a scalar, for a certain user, items with known ratings less
%     than this scalar are viewed as dislike;
%  flag_comprehensive: 0 or 1,  default value: 0; 
%    0: top-k recommendation based on relatedness ( an item is recommend if
%         its predicted rating >= a threshold   AND  relatedness value >=  a    threshold);
%    1:  if a user is recommended  with ``relatedness based top-1 recommendation'',  then use the result of it;
%          otherwise (no item is recommended by `` top-k recommendation based on relatedness''), 
%          use the result of top-k recommendation without   relatedness condition; 
% Outputs:
%   acc_t: a N-by-1 struct array, N: the length of rel_level, refer the output of  presicion_recommend()
%       for its  fields;


[nUser nItem] = size(R);
T = sparse(user_v,item_v,rate_v,nUser,nItem); % generate predicted rating matrix;
Rel = sparse(user_v,item_v,rel_v,nUser,nItem); % generate relatedness rating matrix;

if nargin<=9 
    flag_comprehensive = 0; % default value
end

% initiation
len_rel_level = length(rel_level);
% % pre_v = zeros(len_rel_level,1);
% % num_user_v = zeros(len_rel_level,1);
% % num_item_v = zeros(len_rel_level,1);
if flag_comprehensive
    T0 = top_k_recommend(T,k,goodEntryMark_recommend);
end
% calculate precision over various relatedness levels
for ii=len_rel_level:-1:1
    rel_l = rel_level(ii);
    T1 = T.*(Rel>=rel_l); 
      % top-k recommendation      
    T2 = top_k_recommend(T1,k,goodEntryMark_recommend);
    if flag_comprehensive
         i_user_v = sum(abs(T2),2)==0;
         T2(i_user_v,:) = T0(i_user_v,:);
    end
      % calculate the precision 
    acc_t(ii,1) = presicion_recommend(R,T2,goodEntryMark_acc);
    
end
