% test top_k_precision_rel 
% Sep 2014

clear;

dataset ='ua'; %'eachmovie'; %

resultFileKey = sprintf('acc_top_k_recommend_%s_quiz',dataset);
if ~existFileRecord(resultFileKey)
    addFileRecord({['result' filesep 'top_k_recommend'] resultFileKey,[resultFileKey '.mat']});
end
resultFile = getFileName(resultFileKey);

pad = '0';

chaosFileKey = sprintf('%s_chaos_pad_%s',dataset,pad);
chaosFile = getFileName(chaosFileKey);

filterFlag = 1; % 0 or 1; 
        % 1: remove the hot items
        % 0: employ the total items

setFlag = 1; % setFlag = 1: quiz set; setFlag = 2: test set;
             % setFlag = 3: quiz + test set;
             % Note that for EachMovie dataset, the R_test set is divided
             % to R_test1, R_test2. Thus, we only do top-k recommendation 
             %  on the quiz set for EachMovie dataset
             
if filterFlag
    infFile = sprintf('..\\data\\%s_train_inf.mat',dataset);
    load(infFile,'num_rating_item');
end


if setFlag==1 || setFlag ==3
    load(chaosFile,'R_quiz');  
end
if setFlag==2 || setFlag ==3
    load(chaosFile,'R_test');
end
nModel = size(R_quiz,2);

% load the known entries
if setFlag==1 || setFlag==3
    %trainFile = sprintf('../data/%s_train_quiz.mat',dataset);
    trainFile = getFileName(sprintf('%s_train_quiz',dataset));
    load(trainFile,'Quiz');
    [user_quiz_v item_quiz_v ] = find(Quiz);
end
if setFlag==2 || setFlag==3
    %testFile = sprintf('../data/%s_test.mat',dataset);
    testFile = getFileName(sprintf('%s_test',dataset));
    load(testFile,'Test');
    [user_test_v item_test_v ] = find(Test);
end

% load the relatedness
if setFlag==1 || setFlag==3
    relFile_quiz = getFileName(sprintf('%s_quiz_adaptive_homotopy',dataset));
    load(relFile_quiz,'rel_v');
    rel_quiz_v = rel_v;
end
if setFlag==2 || setFlag==3
    relFile_test = getFileName(sprintf('%s_test_adaptive_homotopy',dataset));
    load(relFile_test,'rel_v');
    rel_test_v = rel_v;
end

% calculate the top-k recommend precision over various relatedness levels
arg.flag_mode = 2; 
arg.k = 1; % top-k recommendation
if arg.flag_mode<=1
    arg.rel_recommend = 3.8;
end
%%arg.rel_level = 4.0; %%%[0; 3.8];
%%rel_level = [0 3.7 3.75 3.8 3.85  3.9];
       % [0;3.4; 3.60; 3.80; 4.0; 4.2]; % on both ua and eachmovie dataset
       % On quiz set, the white sheep are usr-item pairs with rel >=3.6685
       %  (ua(MovieLens) dataset);
       % On test set, this benchmark is 3.5969 (ua(MovieLens) dataset);
if strcmpi(dataset,'ua')
    arg.goodEntryMark_recommend = 4.0;
else
    arg.goodEntryMark_recommend = 5.0; %4.0;  %5.0; % on Eachmovie dataset;                            
end

if strcmpi(dataset,'ua')
    arg.goodEntryMark_acc = 4.0;
else
    arg.goodEntryMark_acc = 5.0; %4.0;  % 5.0 on Eachmovie dataset;  % it is set as 4.0 on ua dataset; 
end

% generate the known score matrix Q, and Relatedness matrix Rel
if setFlag==1
    Q = Quiz;
    Rel = sparse(user_quiz_v,item_quiz_v,rel_quiz_v);
elseif setFlag==2
    Q = Test; 
    Rel = sparse(user_test_v,item_test_v,rel_test_v);
else % setFlag ==3
    % merge Quiz and Test set
    Q = merge_sparse_matrix(Quiz,Test);
    % merge the relatedness values on Quiz and Test set
    Rel_quiz = sparse(user_quiz_v,item_quiz_v,rel_quiz_v);
    Rel_test = sparse(user_test_v,item_test_v,rel_test_v);
    Rel = merge_sparse_matrix(Rel_quiz,Rel_test);
end

if filterFlag
    % remove the hot items
    hot_item_thresh = 80;
        % an item received more than HOT_ITEM_THRESH ratings is viewed as
        % hot, and will be removed;    
    ind = (num_rating_item <= hot_item_thresh);
    n_col_Q = size(Q,2);
    n_col_Rel = size(Rel,2);
    Q = Q(:,ind(1:n_col_Q));
    Rel = Rel(:,ind(1:n_col_Rel));
end
    

for i_nModel=nModel:-1:1       
    if setFlag==1                
        Score_pre = sparse(user_quiz_v,item_quiz_v,R_quiz(:,i_nModel));       
    elseif setFlag==2                
        Score_pre = sparse(user_test_v,item_test_v,R_test(:,i_nModel));
    else % setFlag ==3
        % merge the predicted scores on Quiz and Test set
        Score_quiz = sparse(user_quiz_v,item_quiz_v,R_quiz(:,i_nModel));
        Score_test = sparse(user_test_v,item_test_v,R_test(:,i_nModel));
        Score_pre = merge_sparse_matrix(Score_quiz,Score_test);
    end
    if filterFlag 
        n_col_Score = size(Score_pre,2);
        Score_pre = Score_pre(:,ind(1:n_col_Score)); % remove the hot items
    end
    acc_t(:,i_nModel) = top_k_precision_rel(Q,Score_pre, Rel,arg);
end

% save the result to mat file
items_c = fieldnames(acc_t);
if setFlag == 1    
    acc_quiz_t =  transform_my_struct(acc_t);
    if exist(resultFile,'file')
        save(resultFile,'items_c','acc_quiz_t','-append');
    else
        save(resultFile,'items_c','acc_quiz_t');
    end
elseif  setFlag == 2    
    acc_test_t =  transform_my_struct(acc_t);  
    if exist(resultFile,'file')
        save(resultFile,'items_c','acc_test_t','-append');
    else
        save(resultFile,'items_c','acc_test_t');
    end
else % setFlag =3 
    acc_quiz_test_t =  transform_my_struct(acc_t);  
    if exist(resultFile,'file')
        save(resultFile,'items_c','acc_quiz_test_t','-append');
    else
        save(resultFile,'items_c','acc_quiz_test_t');
    end
end

