function [acc] = presicion_recommend(R,R1,goodEntryMark)
% calculate the recommend precision
%
% Inputs:
%  R: rating matrix, a sparse matrix, containing the real (observed) tested
%    ratings, the nonzero ratings of R contain the nonzero entries of R1;
%  R1: recommendation rating matrix, a sparse matrix with the same size as
%    R, containing the recommeded ratings;
%  goodEntryMark: a scalar, for a certain user, items with ratings not
%     less than this goodEntryMark are viewed as prefered ones 
% Outputs: 
%  acc: structure of accuracies, with the following fields:
%    .num_recom_user: number of  users recommended at least 1 item;
%    .num_recom_item: total number of  recommended items 
%    .num_recom_entry: total number of recommended user-item pairs (entries);
%    .num_hit_entry: number of user-item pairs that recommended correctly (real rating >=goodEntryMark)
%    .num_hit_user: number of users for whom at least 1 item is recommened  correctly;
%    .num_proper_entry: number of total entries with real rating>= goodEntryMark
%    .num_proper_user:  number of total users that there exists at least 1
%       item with real rating >= goodEntryMark;
%    .hr: num_hit_user / num_proper_user; 
%    .pre:  num_hit_entry/ num_recom_entry

BETA = 0;
I = R1~=BETA;
acc.num_recom_entry = nnz(I);
acc.num_recom_user =  nnz(sum(I,2));
acc.num_recom_item = nnz(sum(I,1));

II = R(I)>=goodEntryMark;
acc.num_hit_entry = nnz(II);
acc.num_hit_user =   nnz(sum(II,2));

III = R>=goodEntryMark;
acc.num_proper_entry = nnz(III);
acc.num_proper_user = nnz(sum(III,2));

acc.hr =   acc.num_hit_user / max(acc.num_proper_user,1); % max(*,1): conside the case that  acc.num_proper_user==0;
acc.pre = acc.num_hit_entry/ max(acc.num_recom_entry,1);
