function [acc ]=top_k_precision_rel(R,Score_pre,Rel, arg)
% calculate the precisions of Top-k recommendation based on relatedness values
%
% Inputs:
% R: the rating matrix, a sparse matrix containg at least the real ratings of
%   tested entries; 
% Score_pre: sparse matrix, the predicted rating scores;   
% Rel: sparse matrix, same size as Score_pre, containing the corresponding
%    relatedness values of Score_pre;  
%
% arg: parameter arguments
%  .k: Optional, an integer, top-k recommendation; default value 1; 
%  .rel_recommend: a scalar, threshold of relatedness indicating reliable
%    user-item pairs; effective and required only if arg.flag_mode is set 0
%    or 1;  
%  .goodEntryMark_recommend: a scalar, for a certain user, items with
%     predicted ratings not less than this scalar are viewed as prefered
%     ones; effective and required if flag_mode is set as 0 or 1;
%  .goodEntryMark_acc: a scalar, for a certain user, parameter for
%     calculating the recommendation precision, items with known ratings
%     less  than this scalar are counted as dislike;
%  .flag_mode: Optional,  default value: 0; 
%    0: top-k recommendation based on relatedness ( an item is recommend if
%         its predicted rating >= a threshold   AND  relatedness value >=
%         a threshold); 
%    1:  if a user is recommended  with ``relatedness based top-1
%        recommendation'',  then use the result of it; 
%        otherwise (no item is recommended by `` top-k recommendation based
%        on relatedness''), use the result of top-k recommendation without
%        relatedness condition;  
%    2:  ensure recommend k items (if any) for each user, recommend ratings 
%        combine the relatedness values, in this case arg.rel_recommend,
%        arg.goodEntryMark_recommend do not effect;  
%    3:  ensure recommend k items (if any) for each user, recommend ratings 
%        regardless the relatedness values, in this case arg.rel_recommend, 
%        arg.goodEntryMark_recommend do not effect;  
%    
% Outputs:
%   acc: a structure of accuracies, 
%      refer the output of  presicion_recommend() for detail;


% arguments
if ~isfield(arg,'k') || isempty(arg.k)
    arg.k = 1;
end
if ~isfield(arg,'flag_mode')|| isempty(arg.flag_mode)
    arg.flag_mode = 0;
end

[nUser nItem] = size(R);
Score_pre = adjust_matrix(Score_pre,nUser,nItem);
Rel = adjust_matrix(Rel,nUser,nItem);

if arg.flag_mode==1
    goodEntryMark_rec = 0.01;
    T0 = top_k_recommend(Score_pre,arg.k,goodEntryMark_rec);
end
% calculate precision over various relatedness levels
if arg.flag_mode <=1 % arg.flag_mode is set 0 or 1
    rel_l = arg.rel_recommend;
    T1 = Score_pre.*(Rel>=rel_l);     
end

if arg.flag_mode == 2  || arg.flag_mode == 3
    mid_rate =  (max(max(R)) + min(min(R)))/2; 
    %try1: score_v = (rate_v - mid_rate).*rel_v + A LARGE CONSTANT; 
    %try2: score_v = rate_v.*rel_v;
    %try3: score_v = rate_v - zeta*sqrt(exp(-rel_v)); where zeta>0 is a
    %   constant;    
  
    if arg.flag_mode==2
        %T1 = Score_pre.*Rel;
        %T1 = Score_pre.*Rel -mid_rate*Rel + 100*(Rel>0);
        zeta = 2.0; 
        p = 0.5;
       % T1 = Score_pre  - zeta*sqrt(exp(-Rel)) + 10*(Rel>0);
        
       T1 = Score_pre  - zeta*(exp(-Rel)).^p + 10*(Rel>0);
       % T1 = (Score_pre  - zeta*(exp(-Rel)).^p ).*Rel + 10*(Rel>0);        
        %T1 = (Score_pre  -mid_rate - zeta*sqrt(exp(-Rel))).*Rel + 100*(Rel>0) ;
        %T1 = (Score_pre  -mid_rate +0.1 - zeta*sqrt(exp(-Rel))).*sqrt(Rel) + 100*(Rel>0) ;
        
    else %arg.flag_mode ==3        
        T1 = Score_pre;
    end 
    arg.goodEntryMark_recommend = 0.01; % 0.01: indicating any positive score   
end

% top-k recommendation
T2 = top_k_recommend(T1,arg.k,arg.goodEntryMark_recommend);
if arg.flag_mode == 1
    i_user_v = sum(abs(T2),2)==0;
    T2(i_user_v,:) = T0(i_user_v,:);
end

% calculate the precision
acc  = presicion_recommend(R,T2,arg.goodEntryMark_acc);
