function R1 = top_k_recommend(R,k,goodEntryMark)
% top-k recommendation

% Inputs: 
%   R: a sparse matrix, made up of ratings of users for items, each of the
%      ratings is positive;
%   k: an positive integer, choose k items for each user, according to the
%      descent order of the ratings;
%   goodEntryMark: a scalar, for a certain user, items with ratings not
%     less than this goodEntryMark are viewed as prefered ones which are
%     qulified as recommended ones; 
% Outputs:
%   R1: a sparse matrix, the same size as R, containing the ratings of
%     recommended items, at most k-items for each user;

[nUser nItem] = size(R);
if k > nItem 
    k = nItem;
end

I  = (R>=goodEntryMark);
R1 = R.*I;

%[R2 X2] = sort(sparse(R1),2,'descend');
[R2 X2] = sort(full(R1),2,'descend');
         % a puzzled mablab build-in function sort()

% II: the index matrix indicating the chosen elements
%II = sparse(nUser,nItem);
xx = kron(ones(k,1),(1:nUser)');
yy = reshape(X2(:,1:k),nUser*k,1);
II = sparse(xx,yy,ones(nUser*k,1),nUser,nItem);
R1 = R1.*II;

